# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Mnemonic
"""

INVALID: int = 0
"""
<no docs>
"""
AAA: int = 1
"""
<no docs>
"""
AAD: int = 2
"""
<no docs>
"""
AAM: int = 3
"""
<no docs>
"""
AAS: int = 4
"""
<no docs>
"""
ADC: int = 5
"""
<no docs>
"""
ADCX: int = 6
"""
<no docs>
"""
ADD: int = 7
"""
<no docs>
"""
ADDPD: int = 8
"""
<no docs>
"""
ADDPS: int = 9
"""
<no docs>
"""
ADDSD: int = 10
"""
<no docs>
"""
ADDSS: int = 11
"""
<no docs>
"""
ADDSUBPD: int = 12
"""
<no docs>
"""
ADDSUBPS: int = 13
"""
<no docs>
"""
ADOX: int = 14
"""
<no docs>
"""
AESDEC: int = 15
"""
<no docs>
"""
AESDECLAST: int = 16
"""
<no docs>
"""
AESENC: int = 17
"""
<no docs>
"""
AESENCLAST: int = 18
"""
<no docs>
"""
AESIMC: int = 19
"""
<no docs>
"""
AESKEYGENASSIST: int = 20
"""
<no docs>
"""
AND: int = 21
"""
<no docs>
"""
ANDN: int = 22
"""
<no docs>
"""
ANDNPD: int = 23
"""
<no docs>
"""
ANDNPS: int = 24
"""
<no docs>
"""
ANDPD: int = 25
"""
<no docs>
"""
ANDPS: int = 26
"""
<no docs>
"""
ARPL: int = 27
"""
<no docs>
"""
BEXTR: int = 28
"""
<no docs>
"""
BLCFILL: int = 29
"""
<no docs>
"""
BLCI: int = 30
"""
<no docs>
"""
BLCIC: int = 31
"""
<no docs>
"""
BLCMSK: int = 32
"""
<no docs>
"""
BLCS: int = 33
"""
<no docs>
"""
BLENDPD: int = 34
"""
<no docs>
"""
BLENDPS: int = 35
"""
<no docs>
"""
BLENDVPD: int = 36
"""
<no docs>
"""
BLENDVPS: int = 37
"""
<no docs>
"""
BLSFILL: int = 38
"""
<no docs>
"""
BLSI: int = 39
"""
<no docs>
"""
BLSIC: int = 40
"""
<no docs>
"""
BLSMSK: int = 41
"""
<no docs>
"""
BLSR: int = 42
"""
<no docs>
"""
BNDCL: int = 43
"""
<no docs>
"""
BNDCN: int = 44
"""
<no docs>
"""
BNDCU: int = 45
"""
<no docs>
"""
BNDLDX: int = 46
"""
<no docs>
"""
BNDMK: int = 47
"""
<no docs>
"""
BNDMOV: int = 48
"""
<no docs>
"""
BNDSTX: int = 49
"""
<no docs>
"""
BOUND: int = 50
"""
<no docs>
"""
BSF: int = 51
"""
<no docs>
"""
BSR: int = 52
"""
<no docs>
"""
BSWAP: int = 53
"""
<no docs>
"""
BT: int = 54
"""
<no docs>
"""
BTC: int = 55
"""
<no docs>
"""
BTR: int = 56
"""
<no docs>
"""
BTS: int = 57
"""
<no docs>
"""
BZHI: int = 58
"""
<no docs>
"""
CALL: int = 59
"""
<no docs>
"""
CBW: int = 60
"""
<no docs>
"""
CDQ: int = 61
"""
<no docs>
"""
CDQE: int = 62
"""
<no docs>
"""
CL1INVMB: int = 63
"""
<no docs>
"""
CLAC: int = 64
"""
<no docs>
"""
CLC: int = 65
"""
<no docs>
"""
CLD: int = 66
"""
<no docs>
"""
CLDEMOTE: int = 67
"""
<no docs>
"""
CLFLUSH: int = 68
"""
<no docs>
"""
CLFLUSHOPT: int = 69
"""
<no docs>
"""
CLGI: int = 70
"""
<no docs>
"""
CLI: int = 71
"""
<no docs>
"""
CLRSSBSY: int = 72
"""
<no docs>
"""
CLTS: int = 73
"""
<no docs>
"""
CLWB: int = 74
"""
<no docs>
"""
CLZERO: int = 75
"""
<no docs>
"""
CMC: int = 76
"""
<no docs>
"""
CMOVA: int = 77
"""
<no docs>
"""
CMOVAE: int = 78
"""
<no docs>
"""
CMOVB: int = 79
"""
<no docs>
"""
CMOVBE: int = 80
"""
<no docs>
"""
CMOVE: int = 81
"""
<no docs>
"""
CMOVG: int = 82
"""
<no docs>
"""
CMOVGE: int = 83
"""
<no docs>
"""
CMOVL: int = 84
"""
<no docs>
"""
CMOVLE: int = 85
"""
<no docs>
"""
CMOVNE: int = 86
"""
<no docs>
"""
CMOVNO: int = 87
"""
<no docs>
"""
CMOVNP: int = 88
"""
<no docs>
"""
CMOVNS: int = 89
"""
<no docs>
"""
CMOVO: int = 90
"""
<no docs>
"""
CMOVP: int = 91
"""
<no docs>
"""
CMOVS: int = 92
"""
<no docs>
"""
CMP: int = 93
"""
<no docs>
"""
CMPPD: int = 94
"""
<no docs>
"""
CMPPS: int = 95
"""
<no docs>
"""
CMPSB: int = 96
"""
<no docs>
"""
CMPSD: int = 97
"""
<no docs>
"""
CMPSQ: int = 98
"""
<no docs>
"""
CMPSS: int = 99
"""
<no docs>
"""
CMPSW: int = 100
"""
<no docs>
"""
CMPXCHG: int = 101
"""
<no docs>
"""
CMPXCHG16B: int = 102
"""
<no docs>
"""
CMPXCHG8B: int = 103
"""
<no docs>
"""
COMISD: int = 104
"""
<no docs>
"""
COMISS: int = 105
"""
<no docs>
"""
CPUID: int = 106
"""
<no docs>
"""
CQO: int = 107
"""
<no docs>
"""
CRC32: int = 108
"""
<no docs>
"""
CVTDQ2PD: int = 109
"""
<no docs>
"""
CVTDQ2PS: int = 110
"""
<no docs>
"""
CVTPD2DQ: int = 111
"""
<no docs>
"""
CVTPD2PI: int = 112
"""
<no docs>
"""
CVTPD2PS: int = 113
"""
<no docs>
"""
CVTPI2PD: int = 114
"""
<no docs>
"""
CVTPI2PS: int = 115
"""
<no docs>
"""
CVTPS2DQ: int = 116
"""
<no docs>
"""
CVTPS2PD: int = 117
"""
<no docs>
"""
CVTPS2PI: int = 118
"""
<no docs>
"""
CVTSD2SI: int = 119
"""
<no docs>
"""
CVTSD2SS: int = 120
"""
<no docs>
"""
CVTSI2SD: int = 121
"""
<no docs>
"""
CVTSI2SS: int = 122
"""
<no docs>
"""
CVTSS2SD: int = 123
"""
<no docs>
"""
CVTSS2SI: int = 124
"""
<no docs>
"""
CVTTPD2DQ: int = 125
"""
<no docs>
"""
CVTTPD2PI: int = 126
"""
<no docs>
"""
CVTTPS2DQ: int = 127
"""
<no docs>
"""
CVTTPS2PI: int = 128
"""
<no docs>
"""
CVTTSD2SI: int = 129
"""
<no docs>
"""
CVTTSS2SI: int = 130
"""
<no docs>
"""
CWD: int = 131
"""
<no docs>
"""
CWDE: int = 132
"""
<no docs>
"""
DAA: int = 133
"""
<no docs>
"""
DAS: int = 134
"""
<no docs>
"""
DB: int = 135
"""
<no docs>
"""
DD: int = 136
"""
<no docs>
"""
DEC: int = 137
"""
<no docs>
"""
DIV: int = 138
"""
<no docs>
"""
DIVPD: int = 139
"""
<no docs>
"""
DIVPS: int = 140
"""
<no docs>
"""
DIVSD: int = 141
"""
<no docs>
"""
DIVSS: int = 142
"""
<no docs>
"""
DPPD: int = 143
"""
<no docs>
"""
DPPS: int = 144
"""
<no docs>
"""
DQ: int = 145
"""
<no docs>
"""
DW: int = 146
"""
<no docs>
"""
EMMS: int = 147
"""
<no docs>
"""
ENCLS: int = 148
"""
<no docs>
"""
ENCLU: int = 149
"""
<no docs>
"""
ENCLV: int = 150
"""
<no docs>
"""
ENDBR32: int = 151
"""
<no docs>
"""
ENDBR64: int = 152
"""
<no docs>
"""
ENQCMD: int = 153
"""
<no docs>
"""
ENQCMDS: int = 154
"""
<no docs>
"""
ENTER: int = 155
"""
<no docs>
"""
EXTRACTPS: int = 156
"""
<no docs>
"""
EXTRQ: int = 157
"""
<no docs>
"""
F2XM1: int = 158
"""
<no docs>
"""
FABS: int = 159
"""
<no docs>
"""
FADD: int = 160
"""
<no docs>
"""
FADDP: int = 161
"""
<no docs>
"""
FBLD: int = 162
"""
<no docs>
"""
FBSTP: int = 163
"""
<no docs>
"""
FCHS: int = 164
"""
<no docs>
"""
FCLEX: int = 165
"""
<no docs>
"""
FCMOVB: int = 166
"""
<no docs>
"""
FCMOVBE: int = 167
"""
<no docs>
"""
FCMOVE: int = 168
"""
<no docs>
"""
FCMOVNB: int = 169
"""
<no docs>
"""
FCMOVNBE: int = 170
"""
<no docs>
"""
FCMOVNE: int = 171
"""
<no docs>
"""
FCMOVNU: int = 172
"""
<no docs>
"""
FCMOVU: int = 173
"""
<no docs>
"""
FCOM: int = 174
"""
<no docs>
"""
FCOMI: int = 175
"""
<no docs>
"""
FCOMIP: int = 176
"""
<no docs>
"""
FCOMP: int = 177
"""
<no docs>
"""
FCOMPP: int = 178
"""
<no docs>
"""
FCOS: int = 179
"""
<no docs>
"""
FDECSTP: int = 180
"""
<no docs>
"""
FDISI: int = 181
"""
<no docs>
"""
FDIV: int = 182
"""
<no docs>
"""
FDIVP: int = 183
"""
<no docs>
"""
FDIVR: int = 184
"""
<no docs>
"""
FDIVRP: int = 185
"""
<no docs>
"""
FEMMS: int = 186
"""
<no docs>
"""
FENI: int = 187
"""
<no docs>
"""
FFREE: int = 188
"""
<no docs>
"""
FFREEP: int = 189
"""
<no docs>
"""
FIADD: int = 190
"""
<no docs>
"""
FICOM: int = 191
"""
<no docs>
"""
FICOMP: int = 192
"""
<no docs>
"""
FIDIV: int = 193
"""
<no docs>
"""
FIDIVR: int = 194
"""
<no docs>
"""
FILD: int = 195
"""
<no docs>
"""
FIMUL: int = 196
"""
<no docs>
"""
FINCSTP: int = 197
"""
<no docs>
"""
FINIT: int = 198
"""
<no docs>
"""
FIST: int = 199
"""
<no docs>
"""
FISTP: int = 200
"""
<no docs>
"""
FISTTP: int = 201
"""
<no docs>
"""
FISUB: int = 202
"""
<no docs>
"""
FISUBR: int = 203
"""
<no docs>
"""
FLD: int = 204
"""
<no docs>
"""
FLD1: int = 205
"""
<no docs>
"""
FLDCW: int = 206
"""
<no docs>
"""
FLDENV: int = 207
"""
<no docs>
"""
FLDL2E: int = 208
"""
<no docs>
"""
FLDL2T: int = 209
"""
<no docs>
"""
FLDLG2: int = 210
"""
<no docs>
"""
FLDLN2: int = 211
"""
<no docs>
"""
FLDPI: int = 212
"""
<no docs>
"""
FLDZ: int = 213
"""
<no docs>
"""
FMUL: int = 214
"""
<no docs>
"""
FMULP: int = 215
"""
<no docs>
"""
FNCLEX: int = 216
"""
<no docs>
"""
FNDISI: int = 217
"""
<no docs>
"""
FNENI: int = 218
"""
<no docs>
"""
FNINIT: int = 219
"""
<no docs>
"""
FNOP: int = 220
"""
<no docs>
"""
FNSAVE: int = 221
"""
<no docs>
"""
FNSETPM: int = 222
"""
<no docs>
"""
FNSTCW: int = 223
"""
<no docs>
"""
FNSTENV: int = 224
"""
<no docs>
"""
FNSTSW: int = 225
"""
<no docs>
"""
FPATAN: int = 226
"""
<no docs>
"""
FPREM: int = 227
"""
<no docs>
"""
FPREM1: int = 228
"""
<no docs>
"""
FPTAN: int = 229
"""
<no docs>
"""
FRNDINT: int = 230
"""
<no docs>
"""
FRSTOR: int = 231
"""
<no docs>
"""
FRSTPM: int = 232
"""
<no docs>
"""
FSAVE: int = 233
"""
<no docs>
"""
FSCALE: int = 234
"""
<no docs>
"""
FSETPM: int = 235
"""
<no docs>
"""
FSIN: int = 236
"""
<no docs>
"""
FSINCOS: int = 237
"""
<no docs>
"""
FSQRT: int = 238
"""
<no docs>
"""
FST: int = 239
"""
<no docs>
"""
FSTCW: int = 240
"""
<no docs>
"""
FSTDW: int = 241
"""
<no docs>
"""
FSTENV: int = 242
"""
<no docs>
"""
FSTP: int = 243
"""
<no docs>
"""
FSTPNCE: int = 244
"""
<no docs>
"""
FSTSG: int = 245
"""
<no docs>
"""
FSTSW: int = 246
"""
<no docs>
"""
FSUB: int = 247
"""
<no docs>
"""
FSUBP: int = 248
"""
<no docs>
"""
FSUBR: int = 249
"""
<no docs>
"""
FSUBRP: int = 250
"""
<no docs>
"""
FTST: int = 251
"""
<no docs>
"""
FUCOM: int = 252
"""
<no docs>
"""
FUCOMI: int = 253
"""
<no docs>
"""
FUCOMIP: int = 254
"""
<no docs>
"""
FUCOMP: int = 255
"""
<no docs>
"""
FUCOMPP: int = 256
"""
<no docs>
"""
FXAM: int = 257
"""
<no docs>
"""
FXCH: int = 258
"""
<no docs>
"""
FXRSTOR: int = 259
"""
<no docs>
"""
FXRSTOR64: int = 260
"""
<no docs>
"""
FXSAVE: int = 261
"""
<no docs>
"""
FXSAVE64: int = 262
"""
<no docs>
"""
FXTRACT: int = 263
"""
<no docs>
"""
FYL2X: int = 264
"""
<no docs>
"""
FYL2XP1: int = 265
"""
<no docs>
"""
GETSEC: int = 266
"""
<no docs>
"""
GF2P8AFFINEINVQB: int = 267
"""
<no docs>
"""
GF2P8AFFINEQB: int = 268
"""
<no docs>
"""
GF2P8MULB: int = 269
"""
<no docs>
"""
HADDPD: int = 270
"""
<no docs>
"""
HADDPS: int = 271
"""
<no docs>
"""
HLT: int = 272
"""
<no docs>
"""
HSUBPD: int = 273
"""
<no docs>
"""
HSUBPS: int = 274
"""
<no docs>
"""
IBTS: int = 275
"""
<no docs>
"""
IDIV: int = 276
"""
<no docs>
"""
IMUL: int = 277
"""
<no docs>
"""
IN: int = 278
"""
<no docs>
"""
INC: int = 279
"""
<no docs>
"""
INCSSPD: int = 280
"""
<no docs>
"""
INCSSPQ: int = 281
"""
<no docs>
"""
INSB: int = 282
"""
<no docs>
"""
INSD: int = 283
"""
<no docs>
"""
INSERTPS: int = 284
"""
<no docs>
"""
INSERTQ: int = 285
"""
<no docs>
"""
INSW: int = 286
"""
<no docs>
"""
INT: int = 287
"""
<no docs>
"""
INT1: int = 288
"""
<no docs>
"""
INTO: int = 289
"""
<no docs>
"""
INVD: int = 290
"""
<no docs>
"""
INVEPT: int = 291
"""
<no docs>
"""
INVLPG: int = 292
"""
<no docs>
"""
INVLPGA: int = 293
"""
<no docs>
"""
INVPCID: int = 294
"""
<no docs>
"""
INVVPID: int = 295
"""
<no docs>
"""
IRET: int = 296
"""
<no docs>
"""
JA: int = 297
"""
<no docs>
"""
JAE: int = 298
"""
<no docs>
"""
JB: int = 299
"""
<no docs>
"""
JBE: int = 300
"""
<no docs>
"""
JCXZ: int = 301
"""
<no docs>
"""
JE: int = 302
"""
<no docs>
"""
JECXZ: int = 303
"""
<no docs>
"""
JG: int = 304
"""
<no docs>
"""
JGE: int = 305
"""
<no docs>
"""
JL: int = 306
"""
<no docs>
"""
JLE: int = 307
"""
<no docs>
"""
JMP: int = 308
"""
<no docs>
"""
JMPE: int = 309
"""
<no docs>
"""
JNE: int = 310
"""
<no docs>
"""
JNO: int = 311
"""
<no docs>
"""
JNP: int = 312
"""
<no docs>
"""
JNS: int = 313
"""
<no docs>
"""
JO: int = 314
"""
<no docs>
"""
JP: int = 315
"""
<no docs>
"""
JRCXZ: int = 316
"""
<no docs>
"""
JS: int = 317
"""
<no docs>
"""
KADDB: int = 318
"""
<no docs>
"""
KADDD: int = 319
"""
<no docs>
"""
KADDQ: int = 320
"""
<no docs>
"""
KADDW: int = 321
"""
<no docs>
"""
KANDB: int = 322
"""
<no docs>
"""
KANDD: int = 323
"""
<no docs>
"""
KANDNB: int = 324
"""
<no docs>
"""
KANDND: int = 325
"""
<no docs>
"""
KANDNQ: int = 326
"""
<no docs>
"""
KANDNW: int = 327
"""
<no docs>
"""
KANDQ: int = 328
"""
<no docs>
"""
KANDW: int = 329
"""
<no docs>
"""
KMOVB: int = 330
"""
<no docs>
"""
KMOVD: int = 331
"""
<no docs>
"""
KMOVQ: int = 332
"""
<no docs>
"""
KMOVW: int = 333
"""
<no docs>
"""
KNOTB: int = 334
"""
<no docs>
"""
KNOTD: int = 335
"""
<no docs>
"""
KNOTQ: int = 336
"""
<no docs>
"""
KNOTW: int = 337
"""
<no docs>
"""
KORB: int = 338
"""
<no docs>
"""
KORD: int = 339
"""
<no docs>
"""
KORQ: int = 340
"""
<no docs>
"""
KORTESTB: int = 341
"""
<no docs>
"""
KORTESTD: int = 342
"""
<no docs>
"""
KORTESTQ: int = 343
"""
<no docs>
"""
KORTESTW: int = 344
"""
<no docs>
"""
KORW: int = 345
"""
<no docs>
"""
KSHIFTLB: int = 346
"""
<no docs>
"""
KSHIFTLD: int = 347
"""
<no docs>
"""
KSHIFTLQ: int = 348
"""
<no docs>
"""
KSHIFTLW: int = 349
"""
<no docs>
"""
KSHIFTRB: int = 350
"""
<no docs>
"""
KSHIFTRD: int = 351
"""
<no docs>
"""
KSHIFTRQ: int = 352
"""
<no docs>
"""
KSHIFTRW: int = 353
"""
<no docs>
"""
KTESTB: int = 354
"""
<no docs>
"""
KTESTD: int = 355
"""
<no docs>
"""
KTESTQ: int = 356
"""
<no docs>
"""
KTESTW: int = 357
"""
<no docs>
"""
KUNPCKBW: int = 358
"""
<no docs>
"""
KUNPCKDQ: int = 359
"""
<no docs>
"""
KUNPCKWD: int = 360
"""
<no docs>
"""
KXNORB: int = 361
"""
<no docs>
"""
KXNORD: int = 362
"""
<no docs>
"""
KXNORQ: int = 363
"""
<no docs>
"""
KXNORW: int = 364
"""
<no docs>
"""
KXORB: int = 365
"""
<no docs>
"""
KXORD: int = 366
"""
<no docs>
"""
KXORQ: int = 367
"""
<no docs>
"""
KXORW: int = 368
"""
<no docs>
"""
LAHF: int = 369
"""
<no docs>
"""
LAR: int = 370
"""
<no docs>
"""
LDDQU: int = 371
"""
<no docs>
"""
LDMXCSR: int = 372
"""
<no docs>
"""
LDS: int = 373
"""
<no docs>
"""
LEA: int = 374
"""
<no docs>
"""
LEAVE: int = 375
"""
<no docs>
"""
LES: int = 376
"""
<no docs>
"""
LFENCE: int = 377
"""
<no docs>
"""
LFS: int = 378
"""
<no docs>
"""
LGDT: int = 379
"""
<no docs>
"""
LGS: int = 380
"""
<no docs>
"""
LIDT: int = 381
"""
<no docs>
"""
LLDT: int = 382
"""
<no docs>
"""
LLWPCB: int = 383
"""
<no docs>
"""
LMSW: int = 384
"""
<no docs>
"""
LOADALL: int = 385
"""
<no docs>
"""
LODSB: int = 386
"""
<no docs>
"""
LODSD: int = 387
"""
<no docs>
"""
LODSQ: int = 388
"""
<no docs>
"""
LODSW: int = 389
"""
<no docs>
"""
LOOP: int = 390
"""
<no docs>
"""
LOOPE: int = 391
"""
<no docs>
"""
LOOPNE: int = 392
"""
<no docs>
"""
LSL: int = 393
"""
<no docs>
"""
LSS: int = 394
"""
<no docs>
"""
LTR: int = 395
"""
<no docs>
"""
LWPINS: int = 396
"""
<no docs>
"""
LWPVAL: int = 397
"""
<no docs>
"""
LZCNT: int = 398
"""
<no docs>
"""
MASKMOVDQU: int = 399
"""
<no docs>
"""
MASKMOVQ: int = 400
"""
<no docs>
"""
MAXPD: int = 401
"""
<no docs>
"""
MAXPS: int = 402
"""
<no docs>
"""
MAXSD: int = 403
"""
<no docs>
"""
MAXSS: int = 404
"""
<no docs>
"""
MCOMMIT: int = 405
"""
<no docs>
"""
MFENCE: int = 406
"""
<no docs>
"""
MINPD: int = 407
"""
<no docs>
"""
MINPS: int = 408
"""
<no docs>
"""
MINSD: int = 409
"""
<no docs>
"""
MINSS: int = 410
"""
<no docs>
"""
MONITOR: int = 411
"""
<no docs>
"""
MONITORX: int = 412
"""
<no docs>
"""
MONTMUL: int = 413
"""
<no docs>
"""
MOV: int = 414
"""
<no docs>
"""
MOVAPD: int = 415
"""
<no docs>
"""
MOVAPS: int = 416
"""
<no docs>
"""
MOVBE: int = 417
"""
<no docs>
"""
MOVD: int = 418
"""
<no docs>
"""
MOVDDUP: int = 419
"""
<no docs>
"""
MOVDIR64B: int = 420
"""
<no docs>
"""
MOVDIRI: int = 421
"""
<no docs>
"""
MOVDQ2Q: int = 422
"""
<no docs>
"""
MOVDQA: int = 423
"""
<no docs>
"""
MOVDQU: int = 424
"""
<no docs>
"""
MOVHLPS: int = 425
"""
<no docs>
"""
MOVHPD: int = 426
"""
<no docs>
"""
MOVHPS: int = 427
"""
<no docs>
"""
MOVLHPS: int = 428
"""
<no docs>
"""
MOVLPD: int = 429
"""
<no docs>
"""
MOVLPS: int = 430
"""
<no docs>
"""
MOVMSKPD: int = 431
"""
<no docs>
"""
MOVMSKPS: int = 432
"""
<no docs>
"""
MOVNTDQ: int = 433
"""
<no docs>
"""
MOVNTDQA: int = 434
"""
<no docs>
"""
MOVNTI: int = 435
"""
<no docs>
"""
MOVNTPD: int = 436
"""
<no docs>
"""
MOVNTPS: int = 437
"""
<no docs>
"""
MOVNTQ: int = 438
"""
<no docs>
"""
MOVNTSD: int = 439
"""
<no docs>
"""
MOVNTSS: int = 440
"""
<no docs>
"""
MOVQ: int = 441
"""
<no docs>
"""
MOVQ2DQ: int = 442
"""
<no docs>
"""
MOVSB: int = 443
"""
<no docs>
"""
MOVSD: int = 444
"""
<no docs>
"""
MOVSHDUP: int = 445
"""
<no docs>
"""
MOVSLDUP: int = 446
"""
<no docs>
"""
MOVSQ: int = 447
"""
<no docs>
"""
MOVSS: int = 448
"""
<no docs>
"""
MOVSW: int = 449
"""
<no docs>
"""
MOVSX: int = 450
"""
<no docs>
"""
MOVSXD: int = 451
"""
<no docs>
"""
MOVUPD: int = 452
"""
<no docs>
"""
MOVUPS: int = 453
"""
<no docs>
"""
MOVZX: int = 454
"""
<no docs>
"""
MPSADBW: int = 455
"""
<no docs>
"""
MUL: int = 456
"""
<no docs>
"""
MULPD: int = 457
"""
<no docs>
"""
MULPS: int = 458
"""
<no docs>
"""
MULSD: int = 459
"""
<no docs>
"""
MULSS: int = 460
"""
<no docs>
"""
MULX: int = 461
"""
<no docs>
"""
MWAIT: int = 462
"""
<no docs>
"""
MWAITX: int = 463
"""
<no docs>
"""
NEG: int = 464
"""
<no docs>
"""
NOP: int = 465
"""
<no docs>
"""
NOT: int = 466
"""
<no docs>
"""
OR: int = 467
"""
<no docs>
"""
ORPD: int = 468
"""
<no docs>
"""
ORPS: int = 469
"""
<no docs>
"""
OUT: int = 470
"""
<no docs>
"""
OUTSB: int = 471
"""
<no docs>
"""
OUTSD: int = 472
"""
<no docs>
"""
OUTSW: int = 473
"""
<no docs>
"""
PABSB: int = 474
"""
<no docs>
"""
PABSD: int = 475
"""
<no docs>
"""
PABSW: int = 476
"""
<no docs>
"""
PACKSSDW: int = 477
"""
<no docs>
"""
PACKSSWB: int = 478
"""
<no docs>
"""
PACKUSDW: int = 479
"""
<no docs>
"""
PACKUSWB: int = 480
"""
<no docs>
"""
PADDB: int = 481
"""
<no docs>
"""
PADDD: int = 482
"""
<no docs>
"""
PADDQ: int = 483
"""
<no docs>
"""
PADDSB: int = 484
"""
<no docs>
"""
PADDSW: int = 485
"""
<no docs>
"""
PADDUSB: int = 486
"""
<no docs>
"""
PADDUSW: int = 487
"""
<no docs>
"""
PADDW: int = 488
"""
<no docs>
"""
PALIGNR: int = 489
"""
<no docs>
"""
PAND: int = 490
"""
<no docs>
"""
PANDN: int = 491
"""
<no docs>
"""
PAUSE: int = 492
"""
<no docs>
"""
PAVGB: int = 493
"""
<no docs>
"""
PAVGUSB: int = 494
"""
<no docs>
"""
PAVGW: int = 495
"""
<no docs>
"""
PBLENDVB: int = 496
"""
<no docs>
"""
PBLENDW: int = 497
"""
<no docs>
"""
PCLMULQDQ: int = 498
"""
<no docs>
"""
PCMPEQB: int = 499
"""
<no docs>
"""
PCMPEQD: int = 500
"""
<no docs>
"""
PCMPEQQ: int = 501
"""
<no docs>
"""
PCMPEQW: int = 502
"""
<no docs>
"""
PCMPESTRI: int = 503
"""
<no docs>
"""
PCMPESTRI64: int = 504
"""
<no docs>
"""
PCMPESTRM: int = 505
"""
<no docs>
"""
PCMPESTRM64: int = 506
"""
<no docs>
"""
PCMPGTB: int = 507
"""
<no docs>
"""
PCMPGTD: int = 508
"""
<no docs>
"""
PCMPGTQ: int = 509
"""
<no docs>
"""
PCMPGTW: int = 510
"""
<no docs>
"""
PCMPISTRI: int = 511
"""
<no docs>
"""
PCMPISTRM: int = 512
"""
<no docs>
"""
PCOMMIT: int = 513
"""
<no docs>
"""
PCONFIG: int = 514
"""
<no docs>
"""
PDEP: int = 515
"""
<no docs>
"""
PEXT: int = 516
"""
<no docs>
"""
PEXTRB: int = 517
"""
<no docs>
"""
PEXTRD: int = 518
"""
<no docs>
"""
PEXTRQ: int = 519
"""
<no docs>
"""
PEXTRW: int = 520
"""
<no docs>
"""
PF2ID: int = 521
"""
<no docs>
"""
PF2IW: int = 522
"""
<no docs>
"""
PFACC: int = 523
"""
<no docs>
"""
PFADD: int = 524
"""
<no docs>
"""
PFCMPEQ: int = 525
"""
<no docs>
"""
PFCMPGE: int = 526
"""
<no docs>
"""
PFCMPGT: int = 527
"""
<no docs>
"""
PFMAX: int = 528
"""
<no docs>
"""
PFMIN: int = 529
"""
<no docs>
"""
PFMUL: int = 530
"""
<no docs>
"""
PFNACC: int = 531
"""
<no docs>
"""
PFPNACC: int = 532
"""
<no docs>
"""
PFRCP: int = 533
"""
<no docs>
"""
PFRCPIT1: int = 534
"""
<no docs>
"""
PFRCPIT2: int = 535
"""
<no docs>
"""
PFRCPV: int = 536
"""
<no docs>
"""
PFRSQIT1: int = 537
"""
<no docs>
"""
PFRSQRT: int = 538
"""
<no docs>
"""
PFRSQRTV: int = 539
"""
<no docs>
"""
PFSUB: int = 540
"""
<no docs>
"""
PFSUBR: int = 541
"""
<no docs>
"""
PHADDD: int = 542
"""
<no docs>
"""
PHADDSW: int = 543
"""
<no docs>
"""
PHADDW: int = 544
"""
<no docs>
"""
PHMINPOSUW: int = 545
"""
<no docs>
"""
PHSUBD: int = 546
"""
<no docs>
"""
PHSUBSW: int = 547
"""
<no docs>
"""
PHSUBW: int = 548
"""
<no docs>
"""
PI2FD: int = 549
"""
<no docs>
"""
PI2FW: int = 550
"""
<no docs>
"""
PINSRB: int = 551
"""
<no docs>
"""
PINSRD: int = 552
"""
<no docs>
"""
PINSRQ: int = 553
"""
<no docs>
"""
PINSRW: int = 554
"""
<no docs>
"""
PMADDUBSW: int = 555
"""
<no docs>
"""
PMADDWD: int = 556
"""
<no docs>
"""
PMAXSB: int = 557
"""
<no docs>
"""
PMAXSD: int = 558
"""
<no docs>
"""
PMAXSW: int = 559
"""
<no docs>
"""
PMAXUB: int = 560
"""
<no docs>
"""
PMAXUD: int = 561
"""
<no docs>
"""
PMAXUW: int = 562
"""
<no docs>
"""
PMINSB: int = 563
"""
<no docs>
"""
PMINSD: int = 564
"""
<no docs>
"""
PMINSW: int = 565
"""
<no docs>
"""
PMINUB: int = 566
"""
<no docs>
"""
PMINUD: int = 567
"""
<no docs>
"""
PMINUW: int = 568
"""
<no docs>
"""
PMOVMSKB: int = 569
"""
<no docs>
"""
PMOVSXBD: int = 570
"""
<no docs>
"""
PMOVSXBQ: int = 571
"""
<no docs>
"""
PMOVSXBW: int = 572
"""
<no docs>
"""
PMOVSXDQ: int = 573
"""
<no docs>
"""
PMOVSXWD: int = 574
"""
<no docs>
"""
PMOVSXWQ: int = 575
"""
<no docs>
"""
PMOVZXBD: int = 576
"""
<no docs>
"""
PMOVZXBQ: int = 577
"""
<no docs>
"""
PMOVZXBW: int = 578
"""
<no docs>
"""
PMOVZXDQ: int = 579
"""
<no docs>
"""
PMOVZXWD: int = 580
"""
<no docs>
"""
PMOVZXWQ: int = 581
"""
<no docs>
"""
PMULDQ: int = 582
"""
<no docs>
"""
PMULHRSW: int = 583
"""
<no docs>
"""
PMULHRW: int = 584
"""
<no docs>
"""
PMULHUW: int = 585
"""
<no docs>
"""
PMULHW: int = 586
"""
<no docs>
"""
PMULLD: int = 587
"""
<no docs>
"""
PMULLW: int = 588
"""
<no docs>
"""
PMULUDQ: int = 589
"""
<no docs>
"""
POP: int = 590
"""
<no docs>
"""
POPA: int = 591
"""
<no docs>
"""
POPCNT: int = 592
"""
<no docs>
"""
POPF: int = 593
"""
<no docs>
"""
POR: int = 594
"""
<no docs>
"""
PREFETCH: int = 595
"""
<no docs>
"""
PREFETCHNTA: int = 596
"""
<no docs>
"""
PREFETCHT0: int = 597
"""
<no docs>
"""
PREFETCHT1: int = 598
"""
<no docs>
"""
PREFETCHT2: int = 599
"""
<no docs>
"""
PREFETCHW: int = 600
"""
<no docs>
"""
PREFETCHWT1: int = 601
"""
<no docs>
"""
PSADBW: int = 602
"""
<no docs>
"""
PSHUFB: int = 603
"""
<no docs>
"""
PSHUFD: int = 604
"""
<no docs>
"""
PSHUFHW: int = 605
"""
<no docs>
"""
PSHUFLW: int = 606
"""
<no docs>
"""
PSHUFW: int = 607
"""
<no docs>
"""
PSIGNB: int = 608
"""
<no docs>
"""
PSIGND: int = 609
"""
<no docs>
"""
PSIGNW: int = 610
"""
<no docs>
"""
PSLLD: int = 611
"""
<no docs>
"""
PSLLDQ: int = 612
"""
<no docs>
"""
PSLLQ: int = 613
"""
<no docs>
"""
PSLLW: int = 614
"""
<no docs>
"""
PSRAD: int = 615
"""
<no docs>
"""
PSRAW: int = 616
"""
<no docs>
"""
PSRLD: int = 617
"""
<no docs>
"""
PSRLDQ: int = 618
"""
<no docs>
"""
PSRLQ: int = 619
"""
<no docs>
"""
PSRLW: int = 620
"""
<no docs>
"""
PSUBB: int = 621
"""
<no docs>
"""
PSUBD: int = 622
"""
<no docs>
"""
PSUBQ: int = 623
"""
<no docs>
"""
PSUBSB: int = 624
"""
<no docs>
"""
PSUBSW: int = 625
"""
<no docs>
"""
PSUBUSB: int = 626
"""
<no docs>
"""
PSUBUSW: int = 627
"""
<no docs>
"""
PSUBW: int = 628
"""
<no docs>
"""
PSWAPD: int = 629
"""
<no docs>
"""
PTEST: int = 630
"""
<no docs>
"""
PTWRITE: int = 631
"""
<no docs>
"""
PUNPCKHBW: int = 632
"""
<no docs>
"""
PUNPCKHDQ: int = 633
"""
<no docs>
"""
PUNPCKHQDQ: int = 634
"""
<no docs>
"""
PUNPCKHWD: int = 635
"""
<no docs>
"""
PUNPCKLBW: int = 636
"""
<no docs>
"""
PUNPCKLDQ: int = 637
"""
<no docs>
"""
PUNPCKLQDQ: int = 638
"""
<no docs>
"""
PUNPCKLWD: int = 639
"""
<no docs>
"""
PUSH: int = 640
"""
<no docs>
"""
PUSHA: int = 641
"""
<no docs>
"""
PUSHF: int = 642
"""
<no docs>
"""
PXOR: int = 643
"""
<no docs>
"""
RCL: int = 644
"""
<no docs>
"""
RCPPS: int = 645
"""
<no docs>
"""
RCPSS: int = 646
"""
<no docs>
"""
RCR: int = 647
"""
<no docs>
"""
RDFSBASE: int = 648
"""
<no docs>
"""
RDGSBASE: int = 649
"""
<no docs>
"""
RDMSR: int = 650
"""
<no docs>
"""
RDPID: int = 651
"""
<no docs>
"""
RDPKRU: int = 652
"""
<no docs>
"""
RDPMC: int = 653
"""
<no docs>
"""
RDPRU: int = 654
"""
<no docs>
"""
RDRAND: int = 655
"""
<no docs>
"""
RDSEED: int = 656
"""
<no docs>
"""
RDSSPD: int = 657
"""
<no docs>
"""
RDSSPQ: int = 658
"""
<no docs>
"""
RDTSC: int = 659
"""
<no docs>
"""
RDTSCP: int = 660
"""
<no docs>
"""
RESERVEDNOP: int = 661
"""
<no docs>
"""
RET: int = 662
"""
<no docs>
"""
RETF: int = 663
"""
<no docs>
"""
ROL: int = 664
"""
<no docs>
"""
ROR: int = 665
"""
<no docs>
"""
RORX: int = 666
"""
<no docs>
"""
ROUNDPD: int = 667
"""
<no docs>
"""
ROUNDPS: int = 668
"""
<no docs>
"""
ROUNDSD: int = 669
"""
<no docs>
"""
ROUNDSS: int = 670
"""
<no docs>
"""
RSM: int = 671
"""
<no docs>
"""
RSQRTPS: int = 672
"""
<no docs>
"""
RSQRTSS: int = 673
"""
<no docs>
"""
RSTORSSP: int = 674
"""
<no docs>
"""
SAHF: int = 675
"""
<no docs>
"""
SAL: int = 676
"""
<no docs>
"""
SALC: int = 677
"""
<no docs>
"""
SAR: int = 678
"""
<no docs>
"""
SARX: int = 679
"""
<no docs>
"""
SAVEPREVSSP: int = 680
"""
<no docs>
"""
SBB: int = 681
"""
<no docs>
"""
SCASB: int = 682
"""
<no docs>
"""
SCASD: int = 683
"""
<no docs>
"""
SCASQ: int = 684
"""
<no docs>
"""
SCASW: int = 685
"""
<no docs>
"""
SETA: int = 686
"""
<no docs>
"""
SETAE: int = 687
"""
<no docs>
"""
SETB: int = 688
"""
<no docs>
"""
SETBE: int = 689
"""
<no docs>
"""
SETE: int = 690
"""
<no docs>
"""
SETG: int = 691
"""
<no docs>
"""
SETGE: int = 692
"""
<no docs>
"""
SETL: int = 693
"""
<no docs>
"""
SETLE: int = 694
"""
<no docs>
"""
SETNE: int = 695
"""
<no docs>
"""
SETNO: int = 696
"""
<no docs>
"""
SETNP: int = 697
"""
<no docs>
"""
SETNS: int = 698
"""
<no docs>
"""
SETO: int = 699
"""
<no docs>
"""
SETP: int = 700
"""
<no docs>
"""
SETS: int = 701
"""
<no docs>
"""
SETSSBSY: int = 702
"""
<no docs>
"""
SFENCE: int = 703
"""
<no docs>
"""
SGDT: int = 704
"""
<no docs>
"""
SHA1MSG1: int = 705
"""
<no docs>
"""
SHA1MSG2: int = 706
"""
<no docs>
"""
SHA1NEXTE: int = 707
"""
<no docs>
"""
SHA1RNDS4: int = 708
"""
<no docs>
"""
SHA256MSG1: int = 709
"""
<no docs>
"""
SHA256MSG2: int = 710
"""
<no docs>
"""
SHA256RNDS2: int = 711
"""
<no docs>
"""
SHL: int = 712
"""
<no docs>
"""
SHLD: int = 713
"""
<no docs>
"""
SHLX: int = 714
"""
<no docs>
"""
SHR: int = 715
"""
<no docs>
"""
SHRD: int = 716
"""
<no docs>
"""
SHRX: int = 717
"""
<no docs>
"""
SHUFPD: int = 718
"""
<no docs>
"""
SHUFPS: int = 719
"""
<no docs>
"""
SIDT: int = 720
"""
<no docs>
"""
SKINIT: int = 721
"""
<no docs>
"""
SLDT: int = 722
"""
<no docs>
"""
SLWPCB: int = 723
"""
<no docs>
"""
SMSW: int = 724
"""
<no docs>
"""
SQRTPD: int = 725
"""
<no docs>
"""
SQRTPS: int = 726
"""
<no docs>
"""
SQRTSD: int = 727
"""
<no docs>
"""
SQRTSS: int = 728
"""
<no docs>
"""
STAC: int = 729
"""
<no docs>
"""
STC: int = 730
"""
<no docs>
"""
STD: int = 731
"""
<no docs>
"""
STGI: int = 732
"""
<no docs>
"""
STI: int = 733
"""
<no docs>
"""
STMXCSR: int = 734
"""
<no docs>
"""
STOSB: int = 735
"""
<no docs>
"""
STOSD: int = 736
"""
<no docs>
"""
STOSQ: int = 737
"""
<no docs>
"""
STOSW: int = 738
"""
<no docs>
"""
STR: int = 739
"""
<no docs>
"""
SUB: int = 740
"""
<no docs>
"""
SUBPD: int = 741
"""
<no docs>
"""
SUBPS: int = 742
"""
<no docs>
"""
SUBSD: int = 743
"""
<no docs>
"""
SUBSS: int = 744
"""
<no docs>
"""
SWAPGS: int = 745
"""
<no docs>
"""
SYSCALL: int = 746
"""
<no docs>
"""
SYSENTER: int = 747
"""
<no docs>
"""
SYSEXIT: int = 748
"""
<no docs>
"""
SYSRET: int = 749
"""
<no docs>
"""
T1MSKC: int = 750
"""
<no docs>
"""
TEST: int = 751
"""
<no docs>
"""
TPAUSE: int = 752
"""
<no docs>
"""
TZCNT: int = 753
"""
<no docs>
"""
TZMSK: int = 754
"""
<no docs>
"""
UCOMISD: int = 755
"""
<no docs>
"""
UCOMISS: int = 756
"""
<no docs>
"""
UD0: int = 757
"""
<no docs>
"""
UD1: int = 758
"""
<no docs>
"""
UD2: int = 759
"""
<no docs>
"""
UMONITOR: int = 760
"""
<no docs>
"""
UMOV: int = 761
"""
<no docs>
"""
UMWAIT: int = 762
"""
<no docs>
"""
UNPCKHPD: int = 763
"""
<no docs>
"""
UNPCKHPS: int = 764
"""
<no docs>
"""
UNPCKLPD: int = 765
"""
<no docs>
"""
UNPCKLPS: int = 766
"""
<no docs>
"""
V4FMADDPS: int = 767
"""
<no docs>
"""
V4FMADDSS: int = 768
"""
<no docs>
"""
V4FNMADDPS: int = 769
"""
<no docs>
"""
V4FNMADDSS: int = 770
"""
<no docs>
"""
VADDPD: int = 771
"""
<no docs>
"""
VADDPS: int = 772
"""
<no docs>
"""
VADDSD: int = 773
"""
<no docs>
"""
VADDSS: int = 774
"""
<no docs>
"""
VADDSUBPD: int = 775
"""
<no docs>
"""
VADDSUBPS: int = 776
"""
<no docs>
"""
VAESDEC: int = 777
"""
<no docs>
"""
VAESDECLAST: int = 778
"""
<no docs>
"""
VAESENC: int = 779
"""
<no docs>
"""
VAESENCLAST: int = 780
"""
<no docs>
"""
VAESIMC: int = 781
"""
<no docs>
"""
VAESKEYGENASSIST: int = 782
"""
<no docs>
"""
VALIGND: int = 783
"""
<no docs>
"""
VALIGNQ: int = 784
"""
<no docs>
"""
VANDNPD: int = 785
"""
<no docs>
"""
VANDNPS: int = 786
"""
<no docs>
"""
VANDPD: int = 787
"""
<no docs>
"""
VANDPS: int = 788
"""
<no docs>
"""
VBLENDMPD: int = 789
"""
<no docs>
"""
VBLENDMPS: int = 790
"""
<no docs>
"""
VBLENDPD: int = 791
"""
<no docs>
"""
VBLENDPS: int = 792
"""
<no docs>
"""
VBLENDVPD: int = 793
"""
<no docs>
"""
VBLENDVPS: int = 794
"""
<no docs>
"""
VBROADCASTF128: int = 795
"""
<no docs>
"""
VBROADCASTF32X2: int = 796
"""
<no docs>
"""
VBROADCASTF32X4: int = 797
"""
<no docs>
"""
VBROADCASTF32X8: int = 798
"""
<no docs>
"""
VBROADCASTF64X2: int = 799
"""
<no docs>
"""
VBROADCASTF64X4: int = 800
"""
<no docs>
"""
VBROADCASTI128: int = 801
"""
<no docs>
"""
VBROADCASTI32X2: int = 802
"""
<no docs>
"""
VBROADCASTI32X4: int = 803
"""
<no docs>
"""
VBROADCASTI32X8: int = 804
"""
<no docs>
"""
VBROADCASTI64X2: int = 805
"""
<no docs>
"""
VBROADCASTI64X4: int = 806
"""
<no docs>
"""
VBROADCASTSD: int = 807
"""
<no docs>
"""
VBROADCASTSS: int = 808
"""
<no docs>
"""
VCMPPD: int = 809
"""
<no docs>
"""
VCMPPS: int = 810
"""
<no docs>
"""
VCMPSD: int = 811
"""
<no docs>
"""
VCMPSS: int = 812
"""
<no docs>
"""
VCOMISD: int = 813
"""
<no docs>
"""
VCOMISS: int = 814
"""
<no docs>
"""
VCOMPRESSPD: int = 815
"""
<no docs>
"""
VCOMPRESSPS: int = 816
"""
<no docs>
"""
VCVTDQ2PD: int = 817
"""
<no docs>
"""
VCVTDQ2PS: int = 818
"""
<no docs>
"""
VCVTNE2PS2BF16: int = 819
"""
<no docs>
"""
VCVTNEPS2BF16: int = 820
"""
<no docs>
"""
VCVTPD2DQ: int = 821
"""
<no docs>
"""
VCVTPD2PS: int = 822
"""
<no docs>
"""
VCVTPD2QQ: int = 823
"""
<no docs>
"""
VCVTPD2UDQ: int = 824
"""
<no docs>
"""
VCVTPD2UQQ: int = 825
"""
<no docs>
"""
VCVTPH2PS: int = 826
"""
<no docs>
"""
VCVTPS2DQ: int = 827
"""
<no docs>
"""
VCVTPS2PD: int = 828
"""
<no docs>
"""
VCVTPS2PH: int = 829
"""
<no docs>
"""
VCVTPS2QQ: int = 830
"""
<no docs>
"""
VCVTPS2UDQ: int = 831
"""
<no docs>
"""
VCVTPS2UQQ: int = 832
"""
<no docs>
"""
VCVTQQ2PD: int = 833
"""
<no docs>
"""
VCVTQQ2PS: int = 834
"""
<no docs>
"""
VCVTSD2SI: int = 835
"""
<no docs>
"""
VCVTSD2SS: int = 836
"""
<no docs>
"""
VCVTSD2USI: int = 837
"""
<no docs>
"""
VCVTSI2SD: int = 838
"""
<no docs>
"""
VCVTSI2SS: int = 839
"""
<no docs>
"""
VCVTSS2SD: int = 840
"""
<no docs>
"""
VCVTSS2SI: int = 841
"""
<no docs>
"""
VCVTSS2USI: int = 842
"""
<no docs>
"""
VCVTTPD2DQ: int = 843
"""
<no docs>
"""
VCVTTPD2QQ: int = 844
"""
<no docs>
"""
VCVTTPD2UDQ: int = 845
"""
<no docs>
"""
VCVTTPD2UQQ: int = 846
"""
<no docs>
"""
VCVTTPS2DQ: int = 847
"""
<no docs>
"""
VCVTTPS2QQ: int = 848
"""
<no docs>
"""
VCVTTPS2UDQ: int = 849
"""
<no docs>
"""
VCVTTPS2UQQ: int = 850
"""
<no docs>
"""
VCVTTSD2SI: int = 851
"""
<no docs>
"""
VCVTTSD2USI: int = 852
"""
<no docs>
"""
VCVTTSS2SI: int = 853
"""
<no docs>
"""
VCVTTSS2USI: int = 854
"""
<no docs>
"""
VCVTUDQ2PD: int = 855
"""
<no docs>
"""
VCVTUDQ2PS: int = 856
"""
<no docs>
"""
VCVTUQQ2PD: int = 857
"""
<no docs>
"""
VCVTUQQ2PS: int = 858
"""
<no docs>
"""
VCVTUSI2SD: int = 859
"""
<no docs>
"""
VCVTUSI2SS: int = 860
"""
<no docs>
"""
VDBPSADBW: int = 861
"""
<no docs>
"""
VDIVPD: int = 862
"""
<no docs>
"""
VDIVPS: int = 863
"""
<no docs>
"""
VDIVSD: int = 864
"""
<no docs>
"""
VDIVSS: int = 865
"""
<no docs>
"""
VDPBF16PS: int = 866
"""
<no docs>
"""
VDPPD: int = 867
"""
<no docs>
"""
VDPPS: int = 868
"""
<no docs>
"""
VERR: int = 869
"""
<no docs>
"""
VERW: int = 870
"""
<no docs>
"""
VEXP2PD: int = 871
"""
<no docs>
"""
VEXP2PS: int = 872
"""
<no docs>
"""
VEXPANDPD: int = 873
"""
<no docs>
"""
VEXPANDPS: int = 874
"""
<no docs>
"""
VEXTRACTF128: int = 875
"""
<no docs>
"""
VEXTRACTF32X4: int = 876
"""
<no docs>
"""
VEXTRACTF32X8: int = 877
"""
<no docs>
"""
VEXTRACTF64X2: int = 878
"""
<no docs>
"""
VEXTRACTF64X4: int = 879
"""
<no docs>
"""
VEXTRACTI128: int = 880
"""
<no docs>
"""
VEXTRACTI32X4: int = 881
"""
<no docs>
"""
VEXTRACTI32X8: int = 882
"""
<no docs>
"""
VEXTRACTI64X2: int = 883
"""
<no docs>
"""
VEXTRACTI64X4: int = 884
"""
<no docs>
"""
VEXTRACTPS: int = 885
"""
<no docs>
"""
VFIXUPIMMPD: int = 886
"""
<no docs>
"""
VFIXUPIMMPS: int = 887
"""
<no docs>
"""
VFIXUPIMMSD: int = 888
"""
<no docs>
"""
VFIXUPIMMSS: int = 889
"""
<no docs>
"""
VFMADD132PD: int = 890
"""
<no docs>
"""
VFMADD132PS: int = 891
"""
<no docs>
"""
VFMADD132SD: int = 892
"""
<no docs>
"""
VFMADD132SS: int = 893
"""
<no docs>
"""
VFMADD213PD: int = 894
"""
<no docs>
"""
VFMADD213PS: int = 895
"""
<no docs>
"""
VFMADD213SD: int = 896
"""
<no docs>
"""
VFMADD213SS: int = 897
"""
<no docs>
"""
VFMADD231PD: int = 898
"""
<no docs>
"""
VFMADD231PS: int = 899
"""
<no docs>
"""
VFMADD231SD: int = 900
"""
<no docs>
"""
VFMADD231SS: int = 901
"""
<no docs>
"""
VFMADDPD: int = 902
"""
<no docs>
"""
VFMADDPS: int = 903
"""
<no docs>
"""
VFMADDSD: int = 904
"""
<no docs>
"""
VFMADDSS: int = 905
"""
<no docs>
"""
VFMADDSUB132PD: int = 906
"""
<no docs>
"""
VFMADDSUB132PS: int = 907
"""
<no docs>
"""
VFMADDSUB213PD: int = 908
"""
<no docs>
"""
VFMADDSUB213PS: int = 909
"""
<no docs>
"""
VFMADDSUB231PD: int = 910
"""
<no docs>
"""
VFMADDSUB231PS: int = 911
"""
<no docs>
"""
VFMADDSUBPD: int = 912
"""
<no docs>
"""
VFMADDSUBPS: int = 913
"""
<no docs>
"""
VFMSUB132PD: int = 914
"""
<no docs>
"""
VFMSUB132PS: int = 915
"""
<no docs>
"""
VFMSUB132SD: int = 916
"""
<no docs>
"""
VFMSUB132SS: int = 917
"""
<no docs>
"""
VFMSUB213PD: int = 918
"""
<no docs>
"""
VFMSUB213PS: int = 919
"""
<no docs>
"""
VFMSUB213SD: int = 920
"""
<no docs>
"""
VFMSUB213SS: int = 921
"""
<no docs>
"""
VFMSUB231PD: int = 922
"""
<no docs>
"""
VFMSUB231PS: int = 923
"""
<no docs>
"""
VFMSUB231SD: int = 924
"""
<no docs>
"""
VFMSUB231SS: int = 925
"""
<no docs>
"""
VFMSUBADD132PD: int = 926
"""
<no docs>
"""
VFMSUBADD132PS: int = 927
"""
<no docs>
"""
VFMSUBADD213PD: int = 928
"""
<no docs>
"""
VFMSUBADD213PS: int = 929
"""
<no docs>
"""
VFMSUBADD231PD: int = 930
"""
<no docs>
"""
VFMSUBADD231PS: int = 931
"""
<no docs>
"""
VFMSUBADDPD: int = 932
"""
<no docs>
"""
VFMSUBADDPS: int = 933
"""
<no docs>
"""
VFMSUBPD: int = 934
"""
<no docs>
"""
VFMSUBPS: int = 935
"""
<no docs>
"""
VFMSUBSD: int = 936
"""
<no docs>
"""
VFMSUBSS: int = 937
"""
<no docs>
"""
VFNMADD132PD: int = 938
"""
<no docs>
"""
VFNMADD132PS: int = 939
"""
<no docs>
"""
VFNMADD132SD: int = 940
"""
<no docs>
"""
VFNMADD132SS: int = 941
"""
<no docs>
"""
VFNMADD213PD: int = 942
"""
<no docs>
"""
VFNMADD213PS: int = 943
"""
<no docs>
"""
VFNMADD213SD: int = 944
"""
<no docs>
"""
VFNMADD213SS: int = 945
"""
<no docs>
"""
VFNMADD231PD: int = 946
"""
<no docs>
"""
VFNMADD231PS: int = 947
"""
<no docs>
"""
VFNMADD231SD: int = 948
"""
<no docs>
"""
VFNMADD231SS: int = 949
"""
<no docs>
"""
VFNMADDPD: int = 950
"""
<no docs>
"""
VFNMADDPS: int = 951
"""
<no docs>
"""
VFNMADDSD: int = 952
"""
<no docs>
"""
VFNMADDSS: int = 953
"""
<no docs>
"""
VFNMSUB132PD: int = 954
"""
<no docs>
"""
VFNMSUB132PS: int = 955
"""
<no docs>
"""
VFNMSUB132SD: int = 956
"""
<no docs>
"""
VFNMSUB132SS: int = 957
"""
<no docs>
"""
VFNMSUB213PD: int = 958
"""
<no docs>
"""
VFNMSUB213PS: int = 959
"""
<no docs>
"""
VFNMSUB213SD: int = 960
"""
<no docs>
"""
VFNMSUB213SS: int = 961
"""
<no docs>
"""
VFNMSUB231PD: int = 962
"""
<no docs>
"""
VFNMSUB231PS: int = 963
"""
<no docs>
"""
VFNMSUB231SD: int = 964
"""
<no docs>
"""
VFNMSUB231SS: int = 965
"""
<no docs>
"""
VFNMSUBPD: int = 966
"""
<no docs>
"""
VFNMSUBPS: int = 967
"""
<no docs>
"""
VFNMSUBSD: int = 968
"""
<no docs>
"""
VFNMSUBSS: int = 969
"""
<no docs>
"""
VFPCLASSPD: int = 970
"""
<no docs>
"""
VFPCLASSPS: int = 971
"""
<no docs>
"""
VFPCLASSSD: int = 972
"""
<no docs>
"""
VFPCLASSSS: int = 973
"""
<no docs>
"""
VFRCZPD: int = 974
"""
<no docs>
"""
VFRCZPS: int = 975
"""
<no docs>
"""
VFRCZSD: int = 976
"""
<no docs>
"""
VFRCZSS: int = 977
"""
<no docs>
"""
VGATHERDPD: int = 978
"""
<no docs>
"""
VGATHERDPS: int = 979
"""
<no docs>
"""
VGATHERPF0DPD: int = 980
"""
<no docs>
"""
VGATHERPF0DPS: int = 981
"""
<no docs>
"""
VGATHERPF0QPD: int = 982
"""
<no docs>
"""
VGATHERPF0QPS: int = 983
"""
<no docs>
"""
VGATHERPF1DPD: int = 984
"""
<no docs>
"""
VGATHERPF1DPS: int = 985
"""
<no docs>
"""
VGATHERPF1QPD: int = 986
"""
<no docs>
"""
VGATHERPF1QPS: int = 987
"""
<no docs>
"""
VGATHERQPD: int = 988
"""
<no docs>
"""
VGATHERQPS: int = 989
"""
<no docs>
"""
VGETEXPPD: int = 990
"""
<no docs>
"""
VGETEXPPS: int = 991
"""
<no docs>
"""
VGETEXPSD: int = 992
"""
<no docs>
"""
VGETEXPSS: int = 993
"""
<no docs>
"""
VGETMANTPD: int = 994
"""
<no docs>
"""
VGETMANTPS: int = 995
"""
<no docs>
"""
VGETMANTSD: int = 996
"""
<no docs>
"""
VGETMANTSS: int = 997
"""
<no docs>
"""
VGF2P8AFFINEINVQB: int = 998
"""
<no docs>
"""
VGF2P8AFFINEQB: int = 999
"""
<no docs>
"""
VGF2P8MULB: int = 1000
"""
<no docs>
"""
VHADDPD: int = 1001
"""
<no docs>
"""
VHADDPS: int = 1002
"""
<no docs>
"""
VHSUBPD: int = 1003
"""
<no docs>
"""
VHSUBPS: int = 1004
"""
<no docs>
"""
VINSERTF128: int = 1005
"""
<no docs>
"""
VINSERTF32X4: int = 1006
"""
<no docs>
"""
VINSERTF32X8: int = 1007
"""
<no docs>
"""
VINSERTF64X2: int = 1008
"""
<no docs>
"""
VINSERTF64X4: int = 1009
"""
<no docs>
"""
VINSERTI128: int = 1010
"""
<no docs>
"""
VINSERTI32X4: int = 1011
"""
<no docs>
"""
VINSERTI32X8: int = 1012
"""
<no docs>
"""
VINSERTI64X2: int = 1013
"""
<no docs>
"""
VINSERTI64X4: int = 1014
"""
<no docs>
"""
VINSERTPS: int = 1015
"""
<no docs>
"""
VLDDQU: int = 1016
"""
<no docs>
"""
VLDMXCSR: int = 1017
"""
<no docs>
"""
VMASKMOVDQU: int = 1018
"""
<no docs>
"""
VMASKMOVPD: int = 1019
"""
<no docs>
"""
VMASKMOVPS: int = 1020
"""
<no docs>
"""
VMAXPD: int = 1021
"""
<no docs>
"""
VMAXPS: int = 1022
"""
<no docs>
"""
VMAXSD: int = 1023
"""
<no docs>
"""
VMAXSS: int = 1024
"""
<no docs>
"""
VMCALL: int = 1025
"""
<no docs>
"""
VMCLEAR: int = 1026
"""
<no docs>
"""
VMFUNC: int = 1027
"""
<no docs>
"""
VMINPD: int = 1028
"""
<no docs>
"""
VMINPS: int = 1029
"""
<no docs>
"""
VMINSD: int = 1030
"""
<no docs>
"""
VMINSS: int = 1031
"""
<no docs>
"""
VMLAUNCH: int = 1032
"""
<no docs>
"""
VMLOAD: int = 1033
"""
<no docs>
"""
VMMCALL: int = 1034
"""
<no docs>
"""
VMOVAPD: int = 1035
"""
<no docs>
"""
VMOVAPS: int = 1036
"""
<no docs>
"""
VMOVD: int = 1037
"""
<no docs>
"""
VMOVDDUP: int = 1038
"""
<no docs>
"""
VMOVDQA: int = 1039
"""
<no docs>
"""
VMOVDQA32: int = 1040
"""
<no docs>
"""
VMOVDQA64: int = 1041
"""
<no docs>
"""
VMOVDQU: int = 1042
"""
<no docs>
"""
VMOVDQU16: int = 1043
"""
<no docs>
"""
VMOVDQU32: int = 1044
"""
<no docs>
"""
VMOVDQU64: int = 1045
"""
<no docs>
"""
VMOVDQU8: int = 1046
"""
<no docs>
"""
VMOVHLPS: int = 1047
"""
<no docs>
"""
VMOVHPD: int = 1048
"""
<no docs>
"""
VMOVHPS: int = 1049
"""
<no docs>
"""
VMOVLHPS: int = 1050
"""
<no docs>
"""
VMOVLPD: int = 1051
"""
<no docs>
"""
VMOVLPS: int = 1052
"""
<no docs>
"""
VMOVMSKPD: int = 1053
"""
<no docs>
"""
VMOVMSKPS: int = 1054
"""
<no docs>
"""
VMOVNTDQ: int = 1055
"""
<no docs>
"""
VMOVNTDQA: int = 1056
"""
<no docs>
"""
VMOVNTPD: int = 1057
"""
<no docs>
"""
VMOVNTPS: int = 1058
"""
<no docs>
"""
VMOVQ: int = 1059
"""
<no docs>
"""
VMOVSD: int = 1060
"""
<no docs>
"""
VMOVSHDUP: int = 1061
"""
<no docs>
"""
VMOVSLDUP: int = 1062
"""
<no docs>
"""
VMOVSS: int = 1063
"""
<no docs>
"""
VMOVUPD: int = 1064
"""
<no docs>
"""
VMOVUPS: int = 1065
"""
<no docs>
"""
VMPSADBW: int = 1066
"""
<no docs>
"""
VMPTRLD: int = 1067
"""
<no docs>
"""
VMPTRST: int = 1068
"""
<no docs>
"""
VMREAD: int = 1069
"""
<no docs>
"""
VMRESUME: int = 1070
"""
<no docs>
"""
VMRUN: int = 1071
"""
<no docs>
"""
VMSAVE: int = 1072
"""
<no docs>
"""
VMULPD: int = 1073
"""
<no docs>
"""
VMULPS: int = 1074
"""
<no docs>
"""
VMULSD: int = 1075
"""
<no docs>
"""
VMULSS: int = 1076
"""
<no docs>
"""
VMWRITE: int = 1077
"""
<no docs>
"""
VMXOFF: int = 1078
"""
<no docs>
"""
VMXON: int = 1079
"""
<no docs>
"""
VORPD: int = 1080
"""
<no docs>
"""
VORPS: int = 1081
"""
<no docs>
"""
VP2INTERSECTD: int = 1082
"""
<no docs>
"""
VP2INTERSECTQ: int = 1083
"""
<no docs>
"""
VP4DPWSSD: int = 1084
"""
<no docs>
"""
VP4DPWSSDS: int = 1085
"""
<no docs>
"""
VPABSB: int = 1086
"""
<no docs>
"""
VPABSD: int = 1087
"""
<no docs>
"""
VPABSQ: int = 1088
"""
<no docs>
"""
VPABSW: int = 1089
"""
<no docs>
"""
VPACKSSDW: int = 1090
"""
<no docs>
"""
VPACKSSWB: int = 1091
"""
<no docs>
"""
VPACKUSDW: int = 1092
"""
<no docs>
"""
VPACKUSWB: int = 1093
"""
<no docs>
"""
VPADDB: int = 1094
"""
<no docs>
"""
VPADDD: int = 1095
"""
<no docs>
"""
VPADDQ: int = 1096
"""
<no docs>
"""
VPADDSB: int = 1097
"""
<no docs>
"""
VPADDSW: int = 1098
"""
<no docs>
"""
VPADDUSB: int = 1099
"""
<no docs>
"""
VPADDUSW: int = 1100
"""
<no docs>
"""
VPADDW: int = 1101
"""
<no docs>
"""
VPALIGNR: int = 1102
"""
<no docs>
"""
VPAND: int = 1103
"""
<no docs>
"""
VPANDD: int = 1104
"""
<no docs>
"""
VPANDN: int = 1105
"""
<no docs>
"""
VPANDND: int = 1106
"""
<no docs>
"""
VPANDNQ: int = 1107
"""
<no docs>
"""
VPANDQ: int = 1108
"""
<no docs>
"""
VPAVGB: int = 1109
"""
<no docs>
"""
VPAVGW: int = 1110
"""
<no docs>
"""
VPBLENDD: int = 1111
"""
<no docs>
"""
VPBLENDMB: int = 1112
"""
<no docs>
"""
VPBLENDMD: int = 1113
"""
<no docs>
"""
VPBLENDMQ: int = 1114
"""
<no docs>
"""
VPBLENDMW: int = 1115
"""
<no docs>
"""
VPBLENDVB: int = 1116
"""
<no docs>
"""
VPBLENDW: int = 1117
"""
<no docs>
"""
VPBROADCASTB: int = 1118
"""
<no docs>
"""
VPBROADCASTD: int = 1119
"""
<no docs>
"""
VPBROADCASTMB2Q: int = 1120
"""
<no docs>
"""
VPBROADCASTMW2D: int = 1121
"""
<no docs>
"""
VPBROADCASTQ: int = 1122
"""
<no docs>
"""
VPBROADCASTW: int = 1123
"""
<no docs>
"""
VPCLMULQDQ: int = 1124
"""
<no docs>
"""
VPCMOV: int = 1125
"""
<no docs>
"""
VPCMPB: int = 1126
"""
<no docs>
"""
VPCMPD: int = 1127
"""
<no docs>
"""
VPCMPEQB: int = 1128
"""
<no docs>
"""
VPCMPEQD: int = 1129
"""
<no docs>
"""
VPCMPEQQ: int = 1130
"""
<no docs>
"""
VPCMPEQW: int = 1131
"""
<no docs>
"""
VPCMPESTRI: int = 1132
"""
<no docs>
"""
VPCMPESTRI64: int = 1133
"""
<no docs>
"""
VPCMPESTRM: int = 1134
"""
<no docs>
"""
VPCMPESTRM64: int = 1135
"""
<no docs>
"""
VPCMPGTB: int = 1136
"""
<no docs>
"""
VPCMPGTD: int = 1137
"""
<no docs>
"""
VPCMPGTQ: int = 1138
"""
<no docs>
"""
VPCMPGTW: int = 1139
"""
<no docs>
"""
VPCMPISTRI: int = 1140
"""
<no docs>
"""
VPCMPISTRM: int = 1141
"""
<no docs>
"""
VPCMPQ: int = 1142
"""
<no docs>
"""
VPCMPUB: int = 1143
"""
<no docs>
"""
VPCMPUD: int = 1144
"""
<no docs>
"""
VPCMPUQ: int = 1145
"""
<no docs>
"""
VPCMPUW: int = 1146
"""
<no docs>
"""
VPCMPW: int = 1147
"""
<no docs>
"""
VPCOMB: int = 1148
"""
<no docs>
"""
VPCOMD: int = 1149
"""
<no docs>
"""
VPCOMPRESSB: int = 1150
"""
<no docs>
"""
VPCOMPRESSD: int = 1151
"""
<no docs>
"""
VPCOMPRESSQ: int = 1152
"""
<no docs>
"""
VPCOMPRESSW: int = 1153
"""
<no docs>
"""
VPCOMQ: int = 1154
"""
<no docs>
"""
VPCOMUB: int = 1155
"""
<no docs>
"""
VPCOMUD: int = 1156
"""
<no docs>
"""
VPCOMUQ: int = 1157
"""
<no docs>
"""
VPCOMUW: int = 1158
"""
<no docs>
"""
VPCOMW: int = 1159
"""
<no docs>
"""
VPCONFLICTD: int = 1160
"""
<no docs>
"""
VPCONFLICTQ: int = 1161
"""
<no docs>
"""
VPDPBUSD: int = 1162
"""
<no docs>
"""
VPDPBUSDS: int = 1163
"""
<no docs>
"""
VPDPWSSD: int = 1164
"""
<no docs>
"""
VPDPWSSDS: int = 1165
"""
<no docs>
"""
VPERM2F128: int = 1166
"""
<no docs>
"""
VPERM2I128: int = 1167
"""
<no docs>
"""
VPERMB: int = 1168
"""
<no docs>
"""
VPERMD: int = 1169
"""
<no docs>
"""
VPERMI2B: int = 1170
"""
<no docs>
"""
VPERMI2D: int = 1171
"""
<no docs>
"""
VPERMI2PD: int = 1172
"""
<no docs>
"""
VPERMI2PS: int = 1173
"""
<no docs>
"""
VPERMI2Q: int = 1174
"""
<no docs>
"""
VPERMI2W: int = 1175
"""
<no docs>
"""
VPERMIL2PD: int = 1176
"""
<no docs>
"""
VPERMIL2PS: int = 1177
"""
<no docs>
"""
VPERMILPD: int = 1178
"""
<no docs>
"""
VPERMILPS: int = 1179
"""
<no docs>
"""
VPERMPD: int = 1180
"""
<no docs>
"""
VPERMPS: int = 1181
"""
<no docs>
"""
VPERMQ: int = 1182
"""
<no docs>
"""
VPERMT2B: int = 1183
"""
<no docs>
"""
VPERMT2D: int = 1184
"""
<no docs>
"""
VPERMT2PD: int = 1185
"""
<no docs>
"""
VPERMT2PS: int = 1186
"""
<no docs>
"""
VPERMT2Q: int = 1187
"""
<no docs>
"""
VPERMT2W: int = 1188
"""
<no docs>
"""
VPERMW: int = 1189
"""
<no docs>
"""
VPEXPANDB: int = 1190
"""
<no docs>
"""
VPEXPANDD: int = 1191
"""
<no docs>
"""
VPEXPANDQ: int = 1192
"""
<no docs>
"""
VPEXPANDW: int = 1193
"""
<no docs>
"""
VPEXTRB: int = 1194
"""
<no docs>
"""
VPEXTRD: int = 1195
"""
<no docs>
"""
VPEXTRQ: int = 1196
"""
<no docs>
"""
VPEXTRW: int = 1197
"""
<no docs>
"""
VPGATHERDD: int = 1198
"""
<no docs>
"""
VPGATHERDQ: int = 1199
"""
<no docs>
"""
VPGATHERQD: int = 1200
"""
<no docs>
"""
VPGATHERQQ: int = 1201
"""
<no docs>
"""
VPHADDBD: int = 1202
"""
<no docs>
"""
VPHADDBQ: int = 1203
"""
<no docs>
"""
VPHADDBW: int = 1204
"""
<no docs>
"""
VPHADDD: int = 1205
"""
<no docs>
"""
VPHADDDQ: int = 1206
"""
<no docs>
"""
VPHADDSW: int = 1207
"""
<no docs>
"""
VPHADDUBD: int = 1208
"""
<no docs>
"""
VPHADDUBQ: int = 1209
"""
<no docs>
"""
VPHADDUBW: int = 1210
"""
<no docs>
"""
VPHADDUDQ: int = 1211
"""
<no docs>
"""
VPHADDUWD: int = 1212
"""
<no docs>
"""
VPHADDUWQ: int = 1213
"""
<no docs>
"""
VPHADDW: int = 1214
"""
<no docs>
"""
VPHADDWD: int = 1215
"""
<no docs>
"""
VPHADDWQ: int = 1216
"""
<no docs>
"""
VPHMINPOSUW: int = 1217
"""
<no docs>
"""
VPHSUBBW: int = 1218
"""
<no docs>
"""
VPHSUBD: int = 1219
"""
<no docs>
"""
VPHSUBDQ: int = 1220
"""
<no docs>
"""
VPHSUBSW: int = 1221
"""
<no docs>
"""
VPHSUBW: int = 1222
"""
<no docs>
"""
VPHSUBWD: int = 1223
"""
<no docs>
"""
VPINSRB: int = 1224
"""
<no docs>
"""
VPINSRD: int = 1225
"""
<no docs>
"""
VPINSRQ: int = 1226
"""
<no docs>
"""
VPINSRW: int = 1227
"""
<no docs>
"""
VPLZCNTD: int = 1228
"""
<no docs>
"""
VPLZCNTQ: int = 1229
"""
<no docs>
"""
VPMACSDD: int = 1230
"""
<no docs>
"""
VPMACSDQH: int = 1231
"""
<no docs>
"""
VPMACSDQL: int = 1232
"""
<no docs>
"""
VPMACSSDD: int = 1233
"""
<no docs>
"""
VPMACSSDQH: int = 1234
"""
<no docs>
"""
VPMACSSDQL: int = 1235
"""
<no docs>
"""
VPMACSSWD: int = 1236
"""
<no docs>
"""
VPMACSSWW: int = 1237
"""
<no docs>
"""
VPMACSWD: int = 1238
"""
<no docs>
"""
VPMACSWW: int = 1239
"""
<no docs>
"""
VPMADCSSWD: int = 1240
"""
<no docs>
"""
VPMADCSWD: int = 1241
"""
<no docs>
"""
VPMADD52HUQ: int = 1242
"""
<no docs>
"""
VPMADD52LUQ: int = 1243
"""
<no docs>
"""
VPMADDUBSW: int = 1244
"""
<no docs>
"""
VPMADDWD: int = 1245
"""
<no docs>
"""
VPMASKMOVD: int = 1246
"""
<no docs>
"""
VPMASKMOVQ: int = 1247
"""
<no docs>
"""
VPMAXSB: int = 1248
"""
<no docs>
"""
VPMAXSD: int = 1249
"""
<no docs>
"""
VPMAXSQ: int = 1250
"""
<no docs>
"""
VPMAXSW: int = 1251
"""
<no docs>
"""
VPMAXUB: int = 1252
"""
<no docs>
"""
VPMAXUD: int = 1253
"""
<no docs>
"""
VPMAXUQ: int = 1254
"""
<no docs>
"""
VPMAXUW: int = 1255
"""
<no docs>
"""
VPMINSB: int = 1256
"""
<no docs>
"""
VPMINSD: int = 1257
"""
<no docs>
"""
VPMINSQ: int = 1258
"""
<no docs>
"""
VPMINSW: int = 1259
"""
<no docs>
"""
VPMINUB: int = 1260
"""
<no docs>
"""
VPMINUD: int = 1261
"""
<no docs>
"""
VPMINUQ: int = 1262
"""
<no docs>
"""
VPMINUW: int = 1263
"""
<no docs>
"""
VPMOVB2M: int = 1264
"""
<no docs>
"""
VPMOVD2M: int = 1265
"""
<no docs>
"""
VPMOVDB: int = 1266
"""
<no docs>
"""
VPMOVDW: int = 1267
"""
<no docs>
"""
VPMOVM2B: int = 1268
"""
<no docs>
"""
VPMOVM2D: int = 1269
"""
<no docs>
"""
VPMOVM2Q: int = 1270
"""
<no docs>
"""
VPMOVM2W: int = 1271
"""
<no docs>
"""
VPMOVMSKB: int = 1272
"""
<no docs>
"""
VPMOVQ2M: int = 1273
"""
<no docs>
"""
VPMOVQB: int = 1274
"""
<no docs>
"""
VPMOVQD: int = 1275
"""
<no docs>
"""
VPMOVQW: int = 1276
"""
<no docs>
"""
VPMOVSDB: int = 1277
"""
<no docs>
"""
VPMOVSDW: int = 1278
"""
<no docs>
"""
VPMOVSQB: int = 1279
"""
<no docs>
"""
VPMOVSQD: int = 1280
"""
<no docs>
"""
VPMOVSQW: int = 1281
"""
<no docs>
"""
VPMOVSWB: int = 1282
"""
<no docs>
"""
VPMOVSXBD: int = 1283
"""
<no docs>
"""
VPMOVSXBQ: int = 1284
"""
<no docs>
"""
VPMOVSXBW: int = 1285
"""
<no docs>
"""
VPMOVSXDQ: int = 1286
"""
<no docs>
"""
VPMOVSXWD: int = 1287
"""
<no docs>
"""
VPMOVSXWQ: int = 1288
"""
<no docs>
"""
VPMOVUSDB: int = 1289
"""
<no docs>
"""
VPMOVUSDW: int = 1290
"""
<no docs>
"""
VPMOVUSQB: int = 1291
"""
<no docs>
"""
VPMOVUSQD: int = 1292
"""
<no docs>
"""
VPMOVUSQW: int = 1293
"""
<no docs>
"""
VPMOVUSWB: int = 1294
"""
<no docs>
"""
VPMOVW2M: int = 1295
"""
<no docs>
"""
VPMOVWB: int = 1296
"""
<no docs>
"""
VPMOVZXBD: int = 1297
"""
<no docs>
"""
VPMOVZXBQ: int = 1298
"""
<no docs>
"""
VPMOVZXBW: int = 1299
"""
<no docs>
"""
VPMOVZXDQ: int = 1300
"""
<no docs>
"""
VPMOVZXWD: int = 1301
"""
<no docs>
"""
VPMOVZXWQ: int = 1302
"""
<no docs>
"""
VPMULDQ: int = 1303
"""
<no docs>
"""
VPMULHRSW: int = 1304
"""
<no docs>
"""
VPMULHUW: int = 1305
"""
<no docs>
"""
VPMULHW: int = 1306
"""
<no docs>
"""
VPMULLD: int = 1307
"""
<no docs>
"""
VPMULLQ: int = 1308
"""
<no docs>
"""
VPMULLW: int = 1309
"""
<no docs>
"""
VPMULTISHIFTQB: int = 1310
"""
<no docs>
"""
VPMULUDQ: int = 1311
"""
<no docs>
"""
VPOPCNTB: int = 1312
"""
<no docs>
"""
VPOPCNTD: int = 1313
"""
<no docs>
"""
VPOPCNTQ: int = 1314
"""
<no docs>
"""
VPOPCNTW: int = 1315
"""
<no docs>
"""
VPOR: int = 1316
"""
<no docs>
"""
VPORD: int = 1317
"""
<no docs>
"""
VPORQ: int = 1318
"""
<no docs>
"""
VPPERM: int = 1319
"""
<no docs>
"""
VPROLD: int = 1320
"""
<no docs>
"""
VPROLQ: int = 1321
"""
<no docs>
"""
VPROLVD: int = 1322
"""
<no docs>
"""
VPROLVQ: int = 1323
"""
<no docs>
"""
VPRORD: int = 1324
"""
<no docs>
"""
VPRORQ: int = 1325
"""
<no docs>
"""
VPRORVD: int = 1326
"""
<no docs>
"""
VPRORVQ: int = 1327
"""
<no docs>
"""
VPROTB: int = 1328
"""
<no docs>
"""
VPROTD: int = 1329
"""
<no docs>
"""
VPROTQ: int = 1330
"""
<no docs>
"""
VPROTW: int = 1331
"""
<no docs>
"""
VPSADBW: int = 1332
"""
<no docs>
"""
VPSCATTERDD: int = 1333
"""
<no docs>
"""
VPSCATTERDQ: int = 1334
"""
<no docs>
"""
VPSCATTERQD: int = 1335
"""
<no docs>
"""
VPSCATTERQQ: int = 1336
"""
<no docs>
"""
VPSHAB: int = 1337
"""
<no docs>
"""
VPSHAD: int = 1338
"""
<no docs>
"""
VPSHAQ: int = 1339
"""
<no docs>
"""
VPSHAW: int = 1340
"""
<no docs>
"""
VPSHLB: int = 1341
"""
<no docs>
"""
VPSHLD: int = 1342
"""
<no docs>
"""
VPSHLDD: int = 1343
"""
<no docs>
"""
VPSHLDQ: int = 1344
"""
<no docs>
"""
VPSHLDVD: int = 1345
"""
<no docs>
"""
VPSHLDVQ: int = 1346
"""
<no docs>
"""
VPSHLDVW: int = 1347
"""
<no docs>
"""
VPSHLDW: int = 1348
"""
<no docs>
"""
VPSHLQ: int = 1349
"""
<no docs>
"""
VPSHLW: int = 1350
"""
<no docs>
"""
VPSHRDD: int = 1351
"""
<no docs>
"""
VPSHRDQ: int = 1352
"""
<no docs>
"""
VPSHRDVD: int = 1353
"""
<no docs>
"""
VPSHRDVQ: int = 1354
"""
<no docs>
"""
VPSHRDVW: int = 1355
"""
<no docs>
"""
VPSHRDW: int = 1356
"""
<no docs>
"""
VPSHUFB: int = 1357
"""
<no docs>
"""
VPSHUFBITQMB: int = 1358
"""
<no docs>
"""
VPSHUFD: int = 1359
"""
<no docs>
"""
VPSHUFHW: int = 1360
"""
<no docs>
"""
VPSHUFLW: int = 1361
"""
<no docs>
"""
VPSIGNB: int = 1362
"""
<no docs>
"""
VPSIGND: int = 1363
"""
<no docs>
"""
VPSIGNW: int = 1364
"""
<no docs>
"""
VPSLLD: int = 1365
"""
<no docs>
"""
VPSLLDQ: int = 1366
"""
<no docs>
"""
VPSLLQ: int = 1367
"""
<no docs>
"""
VPSLLVD: int = 1368
"""
<no docs>
"""
VPSLLVQ: int = 1369
"""
<no docs>
"""
VPSLLVW: int = 1370
"""
<no docs>
"""
VPSLLW: int = 1371
"""
<no docs>
"""
VPSRAD: int = 1372
"""
<no docs>
"""
VPSRAQ: int = 1373
"""
<no docs>
"""
VPSRAVD: int = 1374
"""
<no docs>
"""
VPSRAVQ: int = 1375
"""
<no docs>
"""
VPSRAVW: int = 1376
"""
<no docs>
"""
VPSRAW: int = 1377
"""
<no docs>
"""
VPSRLD: int = 1378
"""
<no docs>
"""
VPSRLDQ: int = 1379
"""
<no docs>
"""
VPSRLQ: int = 1380
"""
<no docs>
"""
VPSRLVD: int = 1381
"""
<no docs>
"""
VPSRLVQ: int = 1382
"""
<no docs>
"""
VPSRLVW: int = 1383
"""
<no docs>
"""
VPSRLW: int = 1384
"""
<no docs>
"""
VPSUBB: int = 1385
"""
<no docs>
"""
VPSUBD: int = 1386
"""
<no docs>
"""
VPSUBQ: int = 1387
"""
<no docs>
"""
VPSUBSB: int = 1388
"""
<no docs>
"""
VPSUBSW: int = 1389
"""
<no docs>
"""
VPSUBUSB: int = 1390
"""
<no docs>
"""
VPSUBUSW: int = 1391
"""
<no docs>
"""
VPSUBW: int = 1392
"""
<no docs>
"""
VPTERNLOGD: int = 1393
"""
<no docs>
"""
VPTERNLOGQ: int = 1394
"""
<no docs>
"""
VPTEST: int = 1395
"""
<no docs>
"""
VPTESTMB: int = 1396
"""
<no docs>
"""
VPTESTMD: int = 1397
"""
<no docs>
"""
VPTESTMQ: int = 1398
"""
<no docs>
"""
VPTESTMW: int = 1399
"""
<no docs>
"""
VPTESTNMB: int = 1400
"""
<no docs>
"""
VPTESTNMD: int = 1401
"""
<no docs>
"""
VPTESTNMQ: int = 1402
"""
<no docs>
"""
VPTESTNMW: int = 1403
"""
<no docs>
"""
VPUNPCKHBW: int = 1404
"""
<no docs>
"""
VPUNPCKHDQ: int = 1405
"""
<no docs>
"""
VPUNPCKHQDQ: int = 1406
"""
<no docs>
"""
VPUNPCKHWD: int = 1407
"""
<no docs>
"""
VPUNPCKLBW: int = 1408
"""
<no docs>
"""
VPUNPCKLDQ: int = 1409
"""
<no docs>
"""
VPUNPCKLQDQ: int = 1410
"""
<no docs>
"""
VPUNPCKLWD: int = 1411
"""
<no docs>
"""
VPXOR: int = 1412
"""
<no docs>
"""
VPXORD: int = 1413
"""
<no docs>
"""
VPXORQ: int = 1414
"""
<no docs>
"""
VRANGEPD: int = 1415
"""
<no docs>
"""
VRANGEPS: int = 1416
"""
<no docs>
"""
VRANGESD: int = 1417
"""
<no docs>
"""
VRANGESS: int = 1418
"""
<no docs>
"""
VRCP14PD: int = 1419
"""
<no docs>
"""
VRCP14PS: int = 1420
"""
<no docs>
"""
VRCP14SD: int = 1421
"""
<no docs>
"""
VRCP14SS: int = 1422
"""
<no docs>
"""
VRCP28PD: int = 1423
"""
<no docs>
"""
VRCP28PS: int = 1424
"""
<no docs>
"""
VRCP28SD: int = 1425
"""
<no docs>
"""
VRCP28SS: int = 1426
"""
<no docs>
"""
VRCPPS: int = 1427
"""
<no docs>
"""
VRCPSS: int = 1428
"""
<no docs>
"""
VREDUCEPD: int = 1429
"""
<no docs>
"""
VREDUCEPS: int = 1430
"""
<no docs>
"""
VREDUCESD: int = 1431
"""
<no docs>
"""
VREDUCESS: int = 1432
"""
<no docs>
"""
VRNDSCALEPD: int = 1433
"""
<no docs>
"""
VRNDSCALEPS: int = 1434
"""
<no docs>
"""
VRNDSCALESD: int = 1435
"""
<no docs>
"""
VRNDSCALESS: int = 1436
"""
<no docs>
"""
VROUNDPD: int = 1437
"""
<no docs>
"""
VROUNDPS: int = 1438
"""
<no docs>
"""
VROUNDSD: int = 1439
"""
<no docs>
"""
VROUNDSS: int = 1440
"""
<no docs>
"""
VRSQRT14PD: int = 1441
"""
<no docs>
"""
VRSQRT14PS: int = 1442
"""
<no docs>
"""
VRSQRT14SD: int = 1443
"""
<no docs>
"""
VRSQRT14SS: int = 1444
"""
<no docs>
"""
VRSQRT28PD: int = 1445
"""
<no docs>
"""
VRSQRT28PS: int = 1446
"""
<no docs>
"""
VRSQRT28SD: int = 1447
"""
<no docs>
"""
VRSQRT28SS: int = 1448
"""
<no docs>
"""
VRSQRTPS: int = 1449
"""
<no docs>
"""
VRSQRTSS: int = 1450
"""
<no docs>
"""
VSCALEFPD: int = 1451
"""
<no docs>
"""
VSCALEFPS: int = 1452
"""
<no docs>
"""
VSCALEFSD: int = 1453
"""
<no docs>
"""
VSCALEFSS: int = 1454
"""
<no docs>
"""
VSCATTERDPD: int = 1455
"""
<no docs>
"""
VSCATTERDPS: int = 1456
"""
<no docs>
"""
VSCATTERPF0DPD: int = 1457
"""
<no docs>
"""
VSCATTERPF0DPS: int = 1458
"""
<no docs>
"""
VSCATTERPF0QPD: int = 1459
"""
<no docs>
"""
VSCATTERPF0QPS: int = 1460
"""
<no docs>
"""
VSCATTERPF1DPD: int = 1461
"""
<no docs>
"""
VSCATTERPF1DPS: int = 1462
"""
<no docs>
"""
VSCATTERPF1QPD: int = 1463
"""
<no docs>
"""
VSCATTERPF1QPS: int = 1464
"""
<no docs>
"""
VSCATTERQPD: int = 1465
"""
<no docs>
"""
VSCATTERQPS: int = 1466
"""
<no docs>
"""
VSHUFF32X4: int = 1467
"""
<no docs>
"""
VSHUFF64X2: int = 1468
"""
<no docs>
"""
VSHUFI32X4: int = 1469
"""
<no docs>
"""
VSHUFI64X2: int = 1470
"""
<no docs>
"""
VSHUFPD: int = 1471
"""
<no docs>
"""
VSHUFPS: int = 1472
"""
<no docs>
"""
VSQRTPD: int = 1473
"""
<no docs>
"""
VSQRTPS: int = 1474
"""
<no docs>
"""
VSQRTSD: int = 1475
"""
<no docs>
"""
VSQRTSS: int = 1476
"""
<no docs>
"""
VSTMXCSR: int = 1477
"""
<no docs>
"""
VSUBPD: int = 1478
"""
<no docs>
"""
VSUBPS: int = 1479
"""
<no docs>
"""
VSUBSD: int = 1480
"""
<no docs>
"""
VSUBSS: int = 1481
"""
<no docs>
"""
VTESTPD: int = 1482
"""
<no docs>
"""
VTESTPS: int = 1483
"""
<no docs>
"""
VUCOMISD: int = 1484
"""
<no docs>
"""
VUCOMISS: int = 1485
"""
<no docs>
"""
VUNPCKHPD: int = 1486
"""
<no docs>
"""
VUNPCKHPS: int = 1487
"""
<no docs>
"""
VUNPCKLPD: int = 1488
"""
<no docs>
"""
VUNPCKLPS: int = 1489
"""
<no docs>
"""
VXORPD: int = 1490
"""
<no docs>
"""
VXORPS: int = 1491
"""
<no docs>
"""
VZEROALL: int = 1492
"""
<no docs>
"""
VZEROUPPER: int = 1493
"""
<no docs>
"""
WAIT: int = 1494
"""
<no docs>
"""
WBINVD: int = 1495
"""
<no docs>
"""
WBNOINVD: int = 1496
"""
<no docs>
"""
WRFSBASE: int = 1497
"""
<no docs>
"""
WRGSBASE: int = 1498
"""
<no docs>
"""
WRMSR: int = 1499
"""
<no docs>
"""
WRPKRU: int = 1500
"""
<no docs>
"""
WRSSD: int = 1501
"""
<no docs>
"""
WRSSQ: int = 1502
"""
<no docs>
"""
WRUSSD: int = 1503
"""
<no docs>
"""
WRUSSQ: int = 1504
"""
<no docs>
"""
XABORT: int = 1505
"""
<no docs>
"""
XADD: int = 1506
"""
<no docs>
"""
XBEGIN: int = 1507
"""
<no docs>
"""
XBTS: int = 1508
"""
<no docs>
"""
XCHG: int = 1509
"""
<no docs>
"""
XCRYPTCBC: int = 1510
"""
<no docs>
"""
XCRYPTCFB: int = 1511
"""
<no docs>
"""
XCRYPTCTR: int = 1512
"""
<no docs>
"""
XCRYPTECB: int = 1513
"""
<no docs>
"""
XCRYPTOFB: int = 1514
"""
<no docs>
"""
XEND: int = 1515
"""
<no docs>
"""
XGETBV: int = 1516
"""
<no docs>
"""
XLATB: int = 1517
"""
<no docs>
"""
XOR: int = 1518
"""
<no docs>
"""
XORPD: int = 1519
"""
<no docs>
"""
XORPS: int = 1520
"""
<no docs>
"""
XRSTOR: int = 1521
"""
<no docs>
"""
XRSTOR64: int = 1522
"""
<no docs>
"""
XRSTORS: int = 1523
"""
<no docs>
"""
XRSTORS64: int = 1524
"""
<no docs>
"""
XSAVE: int = 1525
"""
<no docs>
"""
XSAVE64: int = 1526
"""
<no docs>
"""
XSAVEC: int = 1527
"""
<no docs>
"""
XSAVEC64: int = 1528
"""
<no docs>
"""
XSAVEOPT: int = 1529
"""
<no docs>
"""
XSAVEOPT64: int = 1530
"""
<no docs>
"""
XSAVES: int = 1531
"""
<no docs>
"""
XSAVES64: int = 1532
"""
<no docs>
"""
XSETBV: int = 1533
"""
<no docs>
"""
XSHA1: int = 1534
"""
<no docs>
"""
XSHA256: int = 1535
"""
<no docs>
"""
XSTORE: int = 1536
"""
<no docs>
"""
XTEST: int = 1537
"""
<no docs>
"""
RMPADJUST: int = 1538
"""
<no docs>
"""
RMPUPDATE: int = 1539
"""
<no docs>
"""
PSMASH: int = 1540
"""
<no docs>
"""
PVALIDATE: int = 1541
"""
<no docs>
"""
SERIALIZE: int = 1542
"""
<no docs>
"""
XSUSLDTRK: int = 1543
"""
<no docs>
"""
XRESLDTRK: int = 1544
"""
<no docs>
"""
INVLPGB: int = 1545
"""
<no docs>
"""
TLBSYNC: int = 1546
"""
<no docs>
"""
VMGEXIT: int = 1547
"""
<no docs>
"""
GETSECQ: int = 1548
"""
<no docs>
"""
SYSEXITQ: int = 1549
"""
<no docs>
"""
LDTILECFG: int = 1550
"""
<no docs>
"""
TILERELEASE: int = 1551
"""
<no docs>
"""
STTILECFG: int = 1552
"""
<no docs>
"""
TILEZERO: int = 1553
"""
<no docs>
"""
TILELOADDT1: int = 1554
"""
<no docs>
"""
TILESTORED: int = 1555
"""
<no docs>
"""
TILELOADD: int = 1556
"""
<no docs>
"""
TDPBF16PS: int = 1557
"""
<no docs>
"""
TDPBUUD: int = 1558
"""
<no docs>
"""
TDPBUSD: int = 1559
"""
<no docs>
"""
TDPBSUD: int = 1560
"""
<no docs>
"""
TDPBSSD: int = 1561
"""
<no docs>
"""
SYSRETQ: int = 1562
"""
<no docs>
"""
FNSTDW: int = 1563
"""
<no docs>
"""
FNSTSG: int = 1564
"""
<no docs>
"""
RDSHR: int = 1565
"""
<no docs>
"""
WRSHR: int = 1566
"""
<no docs>
"""
SMINT: int = 1567
"""
<no docs>
"""
DMINT: int = 1568
"""
<no docs>
"""
RDM: int = 1569
"""
<no docs>
"""
SVDC: int = 1570
"""
<no docs>
"""
RSDC: int = 1571
"""
<no docs>
"""
SVLDT: int = 1572
"""
<no docs>
"""
RSLDT: int = 1573
"""
<no docs>
"""
SVTS: int = 1574
"""
<no docs>
"""
RSTS: int = 1575
"""
<no docs>
"""
BB0_RESET: int = 1576
"""
<no docs>
"""
BB1_RESET: int = 1577
"""
<no docs>
"""
CPU_WRITE: int = 1578
"""
<no docs>
"""
CPU_READ: int = 1579
"""
<no docs>
"""
ALTINST: int = 1580
"""
<no docs>
"""
PAVEB: int = 1581
"""
<no docs>
"""
PADDSIW: int = 1582
"""
<no docs>
"""
PMAGW: int = 1583
"""
<no docs>
"""
PDISTIB: int = 1584
"""
<no docs>
"""
PSUBSIW: int = 1585
"""
<no docs>
"""
PMVZB: int = 1586
"""
<no docs>
"""
PMVNZB: int = 1587
"""
<no docs>
"""
PMVLZB: int = 1588
"""
<no docs>
"""
PMVGEZB: int = 1589
"""
<no docs>
"""
PMULHRIW: int = 1590
"""
<no docs>
"""
PMACHRIW: int = 1591
"""
<no docs>
"""
FTSTP: int = 1592
"""
<no docs>
"""
FRINT2: int = 1593
"""
<no docs>
"""
FRICHOP: int = 1594
"""
<no docs>
"""
FRINEAR: int = 1595
"""
<no docs>
"""
UNDOC: int = 1596
"""
<no docs>
"""
TDCALL: int = 1597
"""
<no docs>
"""
SEAMRET: int = 1598
"""
<no docs>
"""
SEAMOPS: int = 1599
"""
<no docs>
"""
SEAMCALL: int = 1600
"""
<no docs>
"""
AESENCWIDE128KL: int = 1601
"""
<no docs>
"""
AESDECWIDE128KL: int = 1602
"""
<no docs>
"""
AESENCWIDE256KL: int = 1603
"""
<no docs>
"""
AESDECWIDE256KL: int = 1604
"""
<no docs>
"""
LOADIWKEY: int = 1605
"""
<no docs>
"""
AESENC128KL: int = 1606
"""
<no docs>
"""
AESDEC128KL: int = 1607
"""
<no docs>
"""
AESENC256KL: int = 1608
"""
<no docs>
"""
AESDEC256KL: int = 1609
"""
<no docs>
"""
ENCODEKEY128: int = 1610
"""
<no docs>
"""
ENCODEKEY256: int = 1611
"""
<no docs>
"""
PUSHAD: int = 1612
"""
<no docs>
"""
POPAD: int = 1613
"""
<no docs>
"""
PUSHFD: int = 1614
"""
<no docs>
"""
PUSHFQ: int = 1615
"""
<no docs>
"""
POPFD: int = 1616
"""
<no docs>
"""
POPFQ: int = 1617
"""
<no docs>
"""
IRETD: int = 1618
"""
<no docs>
"""
IRETQ: int = 1619
"""
<no docs>
"""
INT3: int = 1620
"""
<no docs>
"""
UIRET: int = 1621
"""
<no docs>
"""
TESTUI: int = 1622
"""
<no docs>
"""
CLUI: int = 1623
"""
<no docs>
"""
STUI: int = 1624
"""
<no docs>
"""
SENDUIPI: int = 1625
"""
<no docs>
"""
HRESET: int = 1626
"""
<no docs>
"""
CCS_HASH: int = 1627
"""
<no docs>
"""
CCS_ENCRYPT: int = 1628
"""
<no docs>
"""
LKGS: int = 1629
"""
<no docs>
"""
ERETU: int = 1630
"""
<no docs>
"""
ERETS: int = 1631
"""
<no docs>
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Mnemonic condition code selector (eg. ``JGE`` / ``JNL``)
"""

GE: int = 0
"""
``JGE``, ``CMOVGE``, ``SETGE``
"""
NL: int = 1
"""
``JNL``, ``CMOVNL``, ``SETNL``
"""
